@@ -4,13 +4,14 @@ $PYTHON -m jcc \
 --use_full_names \
 --python orekit \
 --version ${PKG_VERSION} \
---jar $SRC_DIR/orekit-9.1.jar \
---jar $SRC_DIR/hipparchus-core-1.2.jar \
---jar $SRC_DIR/hipparchus-fitting-1.2.jar \
---jar $SRC_DIR/hipparchus-geometry-1.2.jar \
---jar $SRC_DIR/hipparchus-ode-1.2.jar \
---jar $SRC_DIR/hipparchus-optim-1.2.jar \
---jar $SRC_DIR/hipparchus-stat-1.2.jar \
+--jar $SRC_DIR/orekit-9.2.jar \
+--jar $SRC_DIR/hipparchus-core-1.3.jar \
+--jar $SRC_DIR/hipparchus-filtering-1.3.jar \
+--jar $SRC_DIR/hipparchus-fitting-1.3.jar \
+--jar $SRC_DIR/hipparchus-geometry-1.3.jar \
+--jar $SRC_DIR/hipparchus-ode-1.3.jar \
+--jar $SRC_DIR/hipparchus-optim-1.3.jar \
+--jar $SRC_DIR/hipparchus-stat-1.3.jar \
 --package java.io \
 --package java.util \
 --package java.text \
@@ -40,7 +41,7 @@ java.util.Locale \
 java.util.Map \
 java.util.Set \
 java.util.TreeSet \
---module $SRC_DIR/pyhelpers \
+--module $SRC_DIR/pyhelpers.py \
 --reserved INFINITE \
 --reserved ERROR \
 --reserved OVERFLOW \
